<div align="center">
  <img src="https://user-images.githubusercontent.com/85283622/206227131-e25b01d8-4c35-4770-a4e9-728655766858.png" width=900></a>
</div>

# OpenNN
A Neural Network implementation from scratch in Python

## Installing pydbops with PyPI :

```sh
pip install open-nn-python
```

## Importing OpenNN:

```sh
import nn
```